==> haskell-structured-0.1.1-291-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-CLStAZk9HYALimQkAudYc2
key:                  structured-0.1.1-CLStAZk9HYALimQkAudYc2
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  a3f52e10319ed9d40ac25973366b89d0
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-CLStAZk9HYALimQkAudYc2
depends:
    aeson-2.1.2.1-30WJrKK1Pbc1pP0H7Lz8HG array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-DUqHedAHAQbJjSb7t2C2Fa binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.5.0-JHGJZlFhSc53NK2NYV614f
    scientific-0.3.8.0-Ksazu1q4lbv7nBtRDhz1zC
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    time-compat-1.9.7-IxEQE3wNsG2EerQ6YOPTZG transformers-0.5.6.2
    unordered-containers-0.2.20-JDDg5JU7nYP5ffg7vR2UZh
    uuid-types-1.0.6-JwDhG2AAhwxL1J85P7XjWi
    vector-0.13.2.0-LerqRcvS8LMBGXOi8GqDsa

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-structured-0.1.1-292-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-KOgQVU8Ogmg5OzutvjTVZh
key:                  structured-0.1.1-KOgQVU8Ogmg5OzutvjTVZh
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  8505e184e56c2a376cfc37fd8a0c4439
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-KOgQVU8Ogmg5OzutvjTVZh
depends:
    aeson-2.1.2.1-4RB85zdNr5p3whZ1np3a31 array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-2HZcxZQrp2G92HohcNwteN binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.5.0-EMf4Iv4OllUGRj72K4SCf0
    scientific-0.3.8.0-75VbuY3tmfA8QFAgCCeEHk
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    time-compat-1.9.7-2W3wF1ggYXz4QsPMsZxlo5 transformers-0.5.6.2
    unordered-containers-0.2.20-L410VxfvorQ5RMb8wocThG
    uuid-types-1.0.6-Z0x6HEqjbREPqi1MVAkGg
    vector-0.13.2.0-B3Rnif6nhJNLHPAZlzHp2g

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
